@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0601';
 
 use Moo;
 use strictures 2;
@@ -46,7 +46,7 @@ sub _build__scale {
 
 
 has notes => (
-    is      => 'ro',
+    is      => 'rw',
     isa     => sub { die "$_[0] is not a valid list" unless ref($_[0]) eq 'ARRAY' },
     default => sub { [] },
 );
@@ -112,7 +112,7 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0600
+version 0.0601
 
 =head1 SYNOPSIS
 
@@ -121,8 +121,9 @@ version 0.0600
   my @notes = qw(C4 E4 D4 G4 C5); # either named notes or midinums
 
   # Chromatic
-  my $md = Music::MelodicDevice::Transposition->new;
-  $md->notes(\@notes);
+  my $md = Music::MelodicDevice::Transposition->new(
+    notes => \@notes,
+  );
   my $transposed = $md->transpose(2); # [D4, F#4, E4, A4, D5]
   $transposed = $md->transpose(4);    # [E4, G#4, F#4, B4, E5]
   $transposed = $md->transpose(4, \@notes); # same thing
@@ -132,6 +133,8 @@ version 0.0600
   $md->notes(\@notes);
   $transposed = $md->transpose(2); # [E4, G4, F4, B4, E5]
   $transposed = $md->transpose(4); # [G4, B4, A4, D5, G5]
+  $md->notes([qw(C4 E4 G4)]);
+  $transposed = $md->transpose(4); # [G4, B4, D5]
 
 =head1 DESCRIPTION
 
